@@ -6,10 +6,10 @@ from queue import Queue
 class Database():
     def __init__(self, name, waiters, executors, engine=None, operational_error=None):
         self.name = name
-        self.status = Queue(1)
+        self.status = DatabaseStatus.RUNNING.value
         self.queries = Queue()
         self.has_queries = threading.Semaphore(value=0)
-        self.is_down=threading.Semaphore(value=1)
+        self._is_down = threading.Lock()
         self.waiters = waiters
         self.executors = executors
         self.engine = engine
@@ -22,6 +22,14 @@ class Database():
             self.waiters[query.wait]._executor = self.executors[query.type]
             self.waiters[query.wait].run_query(query, self)
 
+    def change_status(self, new_status):
+        with self._is_down:
+            self.status = new_status
+
+    def check_status(self):
+        with self._is_down:
+            return self.status
+
 
 class DatabaseStatus(enum.Enum):
     RUNNING = "RUNNING"
