@@ -17,26 +17,24 @@ class WaitWaiter(Waiter):
         super(WaitWaiter, self).__init__(executor)
 
     def run_query(self, query, database):
-        while database.status.get() == DatabaseStatus.RUNNING.value:
+        while database.check_status() == DatabaseStatus.RUNNING.value:
             try:
                 self._executor.run_query(query, database)
                 break
             except django.db.utils.OperationalError:
-                database.status.put(DatabaseStatus.DOWN.value)
-                database.is_down.aquire()
+                database.change_status(DatabaseStatus.DOWN.value)
                 self.wait_for_connection(query, database)
 
     def wait_for_connection(self, query, database):
-        while database.is_down.aquire():
+        while database.check_status() == DatabaseStatus.DOWN.value:
             pass
 
 
 class DontWaitWaiter(Waiter):
     def run_query(self, query, database):
-        if database.status.get() == DatabaseStatus.RUNNING.value:
+        if database.check_status() == DatabaseStatus.RUNNING.value:
             try:
                 self._executor.run_query(query, database)
             except django.db.utils.OperationalError:
-                database.status.put(DatabaseStatus.DOWN.value)
-                database.is_down.aquire()
+                database.change_status(DatabaseStatus.DOWN.value)
                 raise django.db.utils.OperationalError
