@@ -16,9 +16,7 @@ class WatchDog():
             for database in self._databases:
                 try:
                     connections[database.name].connect()
+                    database.change_status(DatabaseStatus.RUNNING.value)
                 except database.operational_error:
-                    database.status.put(DatabaseStatus.DOWN.value)
-                    database.is_down.aquire()
-                else:
-                    database.status.put(DatabaseStatus.RUNNING.value)
-                    database.is_down.release()
+                    database.change_status(DatabaseStatus.DOWN.value)
+
